@@ -60,6 +60,7 @@ class _Resource(object):
     query_one = None
     query_filter = None
     query_create = None
+    query_delete = None
 
     _relations = {}
     __length_hint__ = None  # fixes Python 2.6 list() call on resource object
@@ -155,6 +156,7 @@ class Project(_Resource):
     query_all = '/projects.json'
     query_one = '/projects/{0}.json'
     query_create = '/projects.json'
+    query_delete = '/projects/{0}.json'
 
     _relations = {
         'wiki_pages': None,
@@ -176,6 +178,7 @@ class Issue(_Resource):
     query_one = '/issues/{0}.json'
     query_filter = '/issues.json'
     query_create = '/projects/{project_id}/issues.json'
+    query_delete = '/issues/{0}.json'
 
     _relations = {
         'relations': None,
@@ -214,6 +217,7 @@ class TimeEntry(_Resource):
     query_one = '/time_entries/{0}.json'
     query_filter = '/issues/{issue_id}/time_entries.json'
     query_create = '/time_entries.json'
+    query_delete = '/time_entries/{0}.json'
 
     def __str__(self):
         return str(self.id)
@@ -271,6 +275,7 @@ class WikiPage(_Resource):
     query_filter = '/projects/{project_id}/wiki/index.json'
     query_one = '/projects/{project_id}/wiki/{0}.json'
     query_create = '/projects/{project_id}/wiki/{title}.json'
+    query_delete = '/projects/{project_id}/wiki/{0}.json'
 
     def refresh(self):
         return self.manager.get(self.title, project_id=self.manager.params['project_id'])
@@ -301,6 +306,7 @@ class ProjectMembership(_Resource):
     query_filter = '/projects/{project_id}/memberships.json'
     query_one = '/memberships/{0}.json'
     query_create = '/projects/{project_id}/memberships.json'
+    query_delete = '/memberships/{0}.json'
 
     def __str__(self):
         return str(self.id)
@@ -321,6 +327,7 @@ class IssueCategory(_Resource):
     query_filter = '/projects/{project_id}/issue_categories.json'
     query_one = '/issue_categories/{0}.json'
     query_create = '/projects/{project_id}/issue_categories.json'
+    query_delete = '/issue_categories/{0}.json'
 
 
 class IssueRelation(_Resource):
@@ -331,6 +338,7 @@ class IssueRelation(_Resource):
     query_filter = '/issues/{issue_id}/relations.json'
     query_one = '/relations/{0}.json'
     query_create = '/issues/{issue_id}/relations.json'
+    query_delete = '/relations/{0}.json'
 
     def __str__(self):
         return str(self.id)
@@ -351,6 +359,7 @@ class Version(_Resource):
     query_filter = '/projects/{project_id}/versions.json'
     query_one = '/versions/{0}.json'
     query_create = '/projects/{project_id}/versions.json'
+    query_delete = '/versions/{0}.json'
 
 
 class User(_Resource):
@@ -363,6 +372,7 @@ class User(_Resource):
     query_one = '/users/{0}.json'
     query_filter = '/users.json'
     query_create = '/users.json'
+    query_delete = '/users/{0}.json'
 
     def __str__(self):
         try:
@@ -391,6 +401,7 @@ class Group(_Resource):
     query_all = '/groups.json'
     query_one = '/groups/{0}.json'
     query_create = '/groups.json'
+    query_delete = '/groups/{0}.json'
 
 
 class Role(_Resource):
